@@ -47,7 +47,7 @@ Tested agains Cisco ACS 3.3 and Cisco (ftp://ftp-eng.cisco.com/pub/tacacs/) tac-
 
 package Net::TacacsPlus::Client;
 
-our $VERSION = '1.09';
+our $VERSION = '1.10';
 
 use strict;
 use warnings;
@@ -75,6 +75,7 @@ __PACKAGE__->mk_accessors(qw{
 	session_id
 	seq_no
 	errmsg
+	server_msg
 	authen_method
 	authen_type
 });
@@ -159,16 +160,17 @@ Returns latest error message
 
 =item authenticate(username, password, authen_type)
 
-username		- tacacs+ username
-password		- tacacs+ user password
-authen_type		- TAC_PLUS_AUTHEN_TYPE_ASCII | TAC_PLUS_AUTHEN_TYPE_PAP
-rem_addr                - remote client address (optional, default is 127.0.0.1)
-port                    - remote client port (optional, default is Virtual00)
+username        - tacacs+ username
+password        - tacacs+ user password
+authen_type     - TAC_PLUS_AUTHEN_TYPE_ASCII | TAC_PLUS_AUTHEN_TYPE_PAP
+rem_addr        - remote client address (optional, default is 127.0.0.1)
+port            - remote client port (optional, default is Virtual00)
+new_password    - if set (other than undef) will trigger password change
 
 =cut
 
 sub authenticate {
-	my ($self,$username,$password,$authen_type,$rem_addr,$port) = @_;
+	my ($self,$username,$password,$authen_type,$rem_addr,$port,$new_password) = @_;
 
 	my $status;
 	eval {
@@ -190,7 +192,7 @@ sub authenticate {
 				'session_id' => $self->session_id,
 				'authen_type' => $authen_type,
 				#start
-				'action' => TAC_PLUS_AUTHEN_LOGIN,
+				'action' => (defined $new_password ? TAC_PLUS_AUTHEN_CHPASS : TAC_PLUS_AUTHEN_LOGIN),
 				'user' => $username,
 				'key' => $self->key,
 				'rem_addr' => $rem_addr,
@@ -227,6 +229,8 @@ sub authenticate {
 
 			Net::TacacsPlus::Packet->check_reply($pkt,$reply);
 			$self->seq_no($reply->seq_no()+1);
+			
+			$self->server_msg($reply->server_msg);
 
 			$status=$reply->status();
 			if ($status == TAC_PLUS_AUTHEN_STATUS_GETUSER)
@@ -242,7 +246,7 @@ sub authenticate {
 					'key' => $self->key,
 					);
 				$pkt->send($self->tacacsserver);
-			} elsif ($status == TAC_PLUS_AUTHEN_STATUS_GETPASS)
+			} elsif ($status == TAC_PLUS_AUTHEN_STATUS_GETDATA)
 			{
 				$pkt = Net::TacacsPlus::Packet->new(
 					#header
@@ -255,6 +259,19 @@ sub authenticate {
 					'key' => $self->key,
 					);
 				$pkt->send($self->tacacsserver);
+			} elsif ($status == TAC_PLUS_AUTHEN_STATUS_GETPASS)
+			{
+				$pkt = Net::TacacsPlus::Packet->new(
+					#header
+					'type' => TAC_PLUS_AUTHEN,
+					'seq_no' => $self->seq_no,
+					'session_id' => $self->session_id,
+					#continue
+					'user_msg' => (defined $new_password ? $new_password : $password),
+					'data' => '',
+					'key' => $self->key,
+					);
+				$pkt->send($self->tacacsserver);
 			} elsif ($status == TAC_PLUS_AUTHEN_STATUS_ERROR)
 			{
 				croak('authen status - error');
